@@ -35,7 +35,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Qt
 #include <QAction>
 #include <QHBoxLayout>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 
 namespace Gwenview
 {
